@@ -5,7 +5,9 @@ use socks5_proto::{
     Response,
 };
 use std::{
+    fmt::{Debug, Formatter, Result as FmtResult},
     io::{Error, ErrorKind, Result},
+    net::SocketAddr,
     sync::Arc,
 };
 use tokio::{io::AsyncWriteExt, net::TcpStream};
@@ -16,11 +18,11 @@ pub mod connect;
 
 pub struct IncomingConnection {
     stream: TcpStream,
-    auth: Arc<dyn Auth + Send + Sync + 'static>,
+    auth: Arc<dyn Auth + Send + Sync>,
 }
 
 impl IncomingConnection {
-    pub(crate) fn new(stream: TcpStream, auth: Arc<dyn Auth + Send + Sync + 'static>) -> Self {
+    pub(crate) fn new(stream: TcpStream, auth: Arc<dyn Auth + Send + Sync>) -> Self {
         IncomingConnection { stream, auth }
     }
 
@@ -56,6 +58,21 @@ impl IncomingConnection {
         }
     }
 
+    #[inline]
+    pub fn local_addr(&self) -> Result<SocketAddr> {
+        self.stream.local_addr()
+    }
+
+    #[inline]
+    pub fn peer_addr(&self) -> Result<SocketAddr> {
+        self.stream.peer_addr()
+    }
+
+    #[inline]
+    pub async fn shutdown(&mut self) -> Result<()> {
+        self.stream.shutdown().await
+    }
+
     async fn auth(&mut self) -> Result<()> {
         let hs_req = HandshakeRequest::read_from(&mut self.stream).await?;
         let chosen_method = self.auth.as_handshake_method();
@@ -76,6 +93,15 @@ impl IncomingConnection {
     }
 }
 
+impl Debug for IncomingConnection {
+    fn fmt(&self, f: &mut Formatter<'_>) -> FmtResult {
+        f.debug_struct("IncomingConnection")
+            .field("stream", &self.stream)
+            .finish()
+    }
+}
+
+#[derive(Debug)]
 pub enum Connection {
     Associate(Associate<associate::NeedReply>, Address),
     Bind(Bind<bind::NeedFirstReply>, Address),
